==> pluxml_5.3.orig.tar.gz: PluXml-5.3/core/lang/ro/update.php <==
<?php

$LANG = array(

'L_SAVE_SUCCESSFUL'					=> 'Inregistrarea datelor a avut loc cu succes',
'L_UPDATE_TITLE'					=> 'Actualizare PluXml',
'L_WRONG_PHP_VERSION'				=> 'PluXml necesită PHP 5 sau o versiune mai mare pentru a lucra.',

'L_SELECT_LANG'						=> 'Alegeţi limba dorită',
'L_INPUT_CHANGE'					=> 'Schimbă',

'L_UPDATE_UPTODATE'					=> 'PluXml dvs. este deja actualizat.',
'L_UPDATE_NOT_AVAILABLE'			=> 'Nici o actualizare nu este disponibila.',
'L_UPDATE_BACK'						=> 'Go Back',
'L_UPDATE_WARNING1'					=> 'Acum se va actualiza versiunea dvs. veche de PluXml',
'L_UPDATE_SELECT_VERSION'			=> 'Va rugam sa selectati din lista de mai jos versiunea veche pentru actualizarea PluXml.',
'L_UPDATE_WARNING2'					=> 'In caz ca versiunea dvs. nu o gasiti printre cele enumerate in lista, atunci dvs. folositi o versiune fara pachet de actualizare.<br />Va sugeram sa descarcati cea mai recenta versiune a <a href="http://www.pluxml.org"> PluXml </ a> si de a face o instalare noua.',
'L_UPDATE_WARNING3'					=> 'Pentru orice eventualitate nu uita sa faci o copie de rezerva a datelor.',
'L_UPDATE_START'					=> 'Start actualizare',

'L_UPDATE_ENDED'					=> 'Actualizarea versiunii, %s finalizate.',
'L_UPDATE_INPROGRESS'				=> 'Cerere versiune actualizari',
'L_UPDATE_ERROR'					=> 'O eroare a fost generata in timpul actualizarii.',
'L_UPDATE_SUCCESSFUL'				=> 'Toate actualizarile au fost aplicate cu succes !',

'L_UPDATE_UPDATE_PARAMETERS_FILE'	=> 'Fisierul de actualizare parametres.xml',
'L_UPDATE_CREATE_TAGS_FILE'			=> 'Crearea fisierului tags.xml',
'L_UPDATE_ERR_CREATE_TAGS_FILE'		=> 'Eroare la crearea fisierului tags.xml',
'L_UPDATE_CREATE_THEME_FILE'		=> 'Crearea fisierului de stil',
'L_UPDATE_ERR_CREATE_THEME_FILE'	=> 'Eroare la crearea fisierului',
'L_UPDATE_ARTICLES_CONVERSION'		=> 'Traducerea articolelor pentru noul format',
'L_UPDATE_ERR_FILE_PROCESSING'		=> 'Eroare in timpul procesarii fisierului',
'L_UPDATE_STATICS_MIGRATION'		=> 'Migrarea de pagini statice Fisier',
'L_UPDATE_ERR_STATICS_MIGRATION'	=> 'Eroare in timpul migratiei de fisier de la pagini statice',
'L_UPDATE_CREATE_USERS_FILE'		=> 'Crearea de fisier utilizatori',
'L_UPDATE_ERR_CREATE_USERS_FILE'	=> 'Eroare la crearea dosarului de utilizatori',
'L_UPDATE_USERS_MIGRATION'			=> 'Migratia fisierului utilizatori',
'L_UPDATE_ERR_USERS_MIGRATION'		=> 'Eroare in timpul migratiei de utilizatori',
'L_UPDATE_ERR_NO_USERS'				=> 'Nici un utilizator gasit',
'L_UPDATE_CREATE_HTACCESS_FILE'		=> 'Crearea fisieruli .htaccess',
'L_UPDATE_ERR_CREATE_HTACCESS_FILE'	=> 'Eroare la crearea fisierului .htaccess',
'L_UPDATE_UPDATE_HTACCESS_FILE'		=> 'Actualizaţi fişierul .htaccess',
'L_UPDATE_ERR_UPDATE_HTACCESS_FILE'	=> 'Eroare în timp ce actualizarea fişierul .htaccess',
'L_UPDATE_CATEGORIES_MIGRATION'		=> 'Migratia tipurilor de fisiere',
'L_UPDATE_ERR_CATEGORIES_MIGRATION'	=> 'Eroare in timpul migratiei categorii fisier',
'L_UPDATE_CREATE_PLUGINS_FILE'		=> 'Crearea fisierului plugins.xml',
'L_UPDATE_ERR_CREATE_PLUGINS_FILE'	=> 'Eroare la crearea fisierului plugins.xml',
'L_UPDATE_DELETE_FULLSCREEN_FILE'	=> 'Stergeti fisierul core/admin/fullscreen.php',
'L_UPDATE_ERR_DELETE_FULLSCREEN_FILE'=> 'Eroare la stergerea fisierului core/admin/fullscreen.php',
'L_UPDATE_DELETE_PLXTOOLBAR_FOLDER'	=>	'Stergeti dosarul core/plxtoolbar/',
'L_UPDATE_ERR_DELETE_PLXTOOLBAR_FOLDER' => 'Eroare la stergerea dosarului core/plxtoolbar/',
'L_UPDATE_FILE'						=> 'Fişierul de actualizare',
'L_UPDATE_ERR_FILE'					=> 'Eroare în timpul fişierul de actualizare',
'L_UPDATE_PLUG_MOVEPARAMFILE'		=> 'Migrarea fişierelor de setări parametrii plugin fişierul de configurare',
'L_UPDATE_UPDATE_PLUGINS_FILE'		=> 'Fisierul de actualizare plugins.xml',

);
?>

==> pluxml_5.5.orig.tar.gz: PluXml-5.5/core/lang/ro/update.php <==
<?php

$LANG = array(

'L_SAVE_SUCCESSFUL'					=> 'Inregistrarea datelor a avut loc cu succes',
'L_UPDATE_TITLE'					=> 'Actualizare PluXml',
'L_WRONG_PHP_VERSION'				=> 'PluXml necesită PHP 5 sau o versiune mai mare pentru a lucra.',

'L_SELECT_LANG'						=> 'Alegeţi limba dorită',
'L_INPUT_CHANGE'					=> 'Schimbă',

'L_UPDATE_UPTODATE'					=> 'PluXml dvs. este deja actualizat.',
'L_UPDATE_NOT_AVAILABLE'			=> 'Nici o actualizare nu este disponibila.',
'L_UPDATE_BACK'						=> 'Go Back',
'L_UPDATE_WARNING1'					=> 'Acum se va actualiza versiunea dvs. veche de PluXml',
'L_UPDATE_SELECT_VERSION'			=> 'Va rugam sa selectati din lista de mai jos versiunea veche pentru actualizarea PluXml.',
'L_UPDATE_WARNING2'					=> 'In caz ca versiunea dvs. nu o gasiti printre cele enumerate in lista, atunci dvs. folositi o versiune fara pachet de actualizare.<br />Va sugeram sa descarcati cea mai recenta versiune a <a href="http://www.pluxml.org"> PluXml </ a> si de a face o instalare noua.',
'L_UPDATE_WARNING3'					=> 'Pentru orice eventualitate nu uita sa faci o copie de rezerva a datelor.',
'L_UPDATE_START'					=> 'Start actualizare',

'L_UPDATE_ENDED'					=> 'Actualizarea versiunii, %s finalizate.',
'L_UPDATE_INPROGRESS'				=> 'Cerere versiune actualizari',
'L_UPDATE_ERROR'					=> 'O eroare a fost generata in timpul actualizarii.',
'L_UPDATE_SUCCESSFUL'				=> 'Toate actualizarile au fost aplicate cu succes !',

'L_UPDATE_UPDATE_PARAMETERS_FILE'	=> 'Fisierul de actualizare parametres.xml',
'L_UPDATE_CREATE_TAGS_FILE'			=> 'Crearea fisierului tags.xml',
'L_UPDATE_ERR_CREATE_TAGS_FILE'		=> 'Eroare la crearea fisierului tags.xml',
'L_UPDATE_CREATE_THEME_FILE'		=> 'Crearea fisierului de stil',
'L_UPDATE_ERR_CREATE_THEME_FILE'	=> 'Eroare la crearea fisierului',
'L_UPDATE_ARTICLES_CONVERSION'		=> 'Traducerea articolelor pentru noul format',
'L_UPDATE_ERR_FILE_PROCESSING'		=> 'Eroare in timpul procesarii fisierului',
'L_UPDATE_STATICS_MIGRATION'		=> 'Migrarea de pagini statice Fisier',
'L_UPDATE_ERR_STATICS_MIGRATION'	=> 'Eroare in timpul migratiei de fisier de la pagini statice',
'L_UPDATE_CREATE_USERS_FILE'		=> 'Crearea de fisier utilizatori',
'L_UPDATE_ERR_CREATE_USERS_FILE'	=> 'Eroare la crearea dosarului de utilizatori',
'L_UPDATE_USERS_MIGRATION'			=> 'Migratia fisierului utilizatori',
'L_UPDATE_ERR_USERS_MIGRATION'		=> 'Eroare in timpul migratiei de utilizatori',
'L_UPDATE_ERR_NO_USERS'				=> 'Nici un utilizator gasit',
'L_UPDATE_CREATE_HTACCESS_FILE'		=> 'Crearea fisieruli .htaccess',
'L_UPDATE_ERR_CREATE_HTACCESS_FILE'	=> 'Eroare la crearea fisierului .htaccess',
'L_UPDATE_UPDATE_HTACCESS_FILE'		=> 'Actualizaţi fişierul .htaccess',
'L_UPDATE_ERR_UPDATE_HTACCESS_FILE'	=> 'Eroare în timp ce actualizarea fişierul .htaccess',
'L_UPDATE_CATEGORIES_MIGRATION'		=> 'Migratia tipurilor de fisiere',
'L_UPDATE_ERR_CATEGORIES_MIGRATION'	=> 'Eroare in timpul migratiei categorii fisier',
'L_UPDATE_CREATE_PLUGINS_FILE'		=> 'Crearea fisierului plugins.xml',
'L_UPDATE_ERR_CREATE_PLUGINS_FILE'	=> 'Eroare la crearea fisierului plugins.xml',
'L_UPDATE_DELETE_FULLSCREEN_FILE'	=> 'Stergeti fisierul core/admin/fullscreen.php',
'L_UPDATE_ERR_DELETE_FULLSCREEN_FILE'=> 'Eroare la stergerea fisierului core/admin/fullscreen.php',
'L_UPDATE_DELETE_PLXTOOLBAR_FOLDER'	=>	'Stergeti dosarul core/plxtoolbar/',
'L_UPDATE_ERR_DELETE_PLXTOOLBAR_FOLDER' => 'Eroare la stergerea dosarului core/plxtoolbar/',
'L_UPDATE_FILE'						=> 'Fişierul de actualizare',
'L_UPDATE_ERR_FILE'					=> 'Eroare în timpul fişierul de actualizare',
'L_UPDATE_PLUG_MOVEPARAMFILE'		=> 'Migrarea fişierelor de setări parametrii plugin fişierul de configurare',
'L_UPDATE_UPDATE_PLUGINS_FILE'		=> 'Fisierul de actualizare plugins.xml',
'L_UPDATE_COMMENTS_MIGRATION'		=> 'Comentariile de migrare',
'L_UPDATE_ERR_COMMENTS_MIGRATION'	=> 'Eroare la migrarea comentarii',
);
?>
